/*
 * bmon/attr.h		Attributes
 *
 * Copyright (c) 2001-2005 Thomas Graf <tgraf@suug.ch>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

#ifndef __BMON_ATTR_H_
#define __BMON_ATTR_H_

#include <bmon/bmon.h>

#define ATTR_TYPE_IGN_OFLOWS	1
#define ATTR_TYPE_IS_RATE	2
#define ATTR_TYPE_IS_USAGE	4

struct attr_type {
	int	at_id;
	char *	at_name;
	char *	at_desc;
	int	at_flags;
	struct unit * at_unit;

	struct attr_type * at_next_name;
	struct attr_type * at_next_id;
};

struct attr_map {
	int	am_id;
	char *	am_name;
};

enum {
	BYTES,
	PACKETS,
	ERRORS,
	DROP,
	FIFO,
	FRAME,
	COMPRESSED,
	MULTICAST,
	OVERLIMITS,
	BPS,
	PPS,
	QLEN,
	BACKLOG,
	REQUEUES,
	COLLISIONS,
	LENGTH_ERRORS,
	OVER_ERRORS,
	CRC_ERRORS,
	MISSED_ERRORS,
	ABORTED_ERRORS,
	HEARTBEAT_ERRORS,
	WINDOW_ERRORS,
	CARRIER_ERRORS
};

extern struct attr_map attrs[];

#define ATTR(_TYPE)	(attrs[(_TYPE)].am_id)

extern struct attr_type *lookup_attrtype(const char *);
extern struct attr_type *lookup_attrtype_byid(int);
extern int attr_name2type(const char *);
extern const char *attr_type2name(int);
extern const char *attr_type2desc(int);
extern int attr_ignore_overflows(int);
extern int attr_is_rate(int);
extern int attr_is_usage(int);
extern struct unit *attr_unit(int);
extern int foreach_attr_type(int (*cb)(struct attr_type *, void *), void *);

extern int attr_resolve_map(struct attr_map *, int);
extern int attr_resolve_global_map(void);

extern void add_attribute(const char *name, const char *desc, const char *unit,
			  const char *flags);

#endif
