/*
 * bmon/graph.h            Graph creation utility
 *
 * Copyright (c) 2001-2004 Thomas Graf <tgraf@suug.ch>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

#ifndef __BMON_GRAPH_H_
#define __BMON_GRAPH_H_

#include <bmon/bmon.h>
#include <bmon/item.h>
#include <bmon/unit.h>

#define D_ROW_SIZE (HISTORY_SIZE + 1)
#define D_AT_ROW(P,R) ((P) + ((R) * D_ROW_SIZE))
#define D_AT_COL(P, R) ((P) + (R))

struct table {
	int			t_index;
	int			t_height;
	char *			t_data;
	char *			t_x_unit;
	char *			t_y_unit;
	double *		t_y_scale;
};

#define GRAPH_HAS_FREEABLE_X_UNIT 1

struct graph {
	int			g_flags;
	struct table		g_rx;
	struct table		g_tx;
};
	
extern void free_graph(struct graph *);
extern struct graph *create_graph(struct hist_elem *, int, struct unit *);
extern struct graph *create_configured_graph(struct history *, int,
					     struct unit *, int);

extern void new_graph(void);
extern void del_graph(void);
extern int next_graph(void);
extern int prev_graph(void);

#endif
