/*
 * bmon/group.h		Group Management
 *
 * Copyright (c) 2001-2005 Thomas Graf <tgraf@suug.ch>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

#ifndef __BMON_GROUP_H_
#define __BMON_GROUP_H_

#include <bmon/bmon.h>

struct item;

struct group_data
{
	char *			gd_name;
	char *			gd_title;
	char *			gd_left_maj_title;
	char *			gd_left_min_title;
	char *			gd_right_maj_title;
	char *			gd_right_min_title;

	struct group_data *	gd_next;
};

struct item_group
{
	char *			g_name;
	struct group_data *	g_data;

	struct item *		g_items;
	struct item *		g_items_tail;
	struct item *		g_selected;
	size_t			g_nitems;

	b_cnt_t			g_rx_maj_total;
	b_cnt_t			g_tx_maj_total;
	b_cnt_t			g_rx_min_total;
	b_cnt_t			g_tx_min_total;
	struct unit *		g_maj_unit;
	struct unit *		g_min_unit;

	struct item_group *	g_next;
	struct item_group *	g_prev;
};

extern struct group_data *lookup_group_data(const char *name);
extern void add_group_def(const char *name, const char *title,
			  const char *left_maj_title,
			  const char *left_min_title,
			  const char *right_maj_title,
			  const char *right_min_title);
extern void add_group_derived(const char *name, const char *title,
			      const char *template);

#endif
