/*
 * bmon/node.h		Node Management
 *
 * Copyright (c) 2001-2004 Thomas Graf <tgraf@suug.ch>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

#ifndef __BMON_NODE_H_
#define __BMON_NODE_H_

#include <bmon/bmon.h>
#include <bmon/item.h>
#include <bmon/group.h>

struct node
{
	int			n_index;
	char *			n_name;
	char *			n_from;
	struct item_group *	n_groups;
	struct item_group *	n_groups_tail;
	int			n_ngroups;
	struct item_group *     n_current_group;
};


extern struct node * lookup_node(const char *name, int creat);
extern struct node * get_local_node(void);
extern int get_nnodes(void);
extern struct node *get_node(int index);
extern int get_ngroups(void);
extern void reset_nodes(void);
extern void remove_unused_node_items(void);

extern struct node * get_current_node(void);
extern struct item * get_current_item(void);
extern int next_item(void);
extern int prev_item(void);
extern int goto_item(int);

extern void calc_node_rates(void);
extern void calc_node_rate(struct node *);


extern struct item_group *get_group(struct node *node, const char *name, int creat);

extern void foreach_node(void (*cb)(struct node *, void *), void *);
extern void foreach_group(struct node *, void (*cb)(struct item_group *, void *), void *);
extern void foreach_item(struct item_group *, void (*cb)(struct item *, void *), void *);
extern void foreach_item_deep(void (*cb)(struct node *, struct item_group *,
					 struct item *, void *), void *);

extern const char * get_local_nodename(void);

extern int first_node(void);
extern int last_node(void);
extern int prev_node(void);
extern int next_node(void);

extern int first_group(void);
extern int last_group(void);
extern int next_group(void);
extern int prev_group(void);

extern int first_item(void);
extern int last_item(void);
extern int next_item(void);
extern int prev_item(void);

#endif
